===========
ridesystems
===========


This is an interface with the RideSystems data.


Description
===========

One half of this is a python interface to the RideSystem's open API, and one half is a scraper that creates an API to
the data on the reports that are accessible on their website.
